==> starship-1.24.0.tar.gz: starship-1.24.0/docs/uk-UA/presets/README.md <==
# Шаблони

Тут ви можете переглянути добірку шаблонів налаштувань, створених спільнотою Starship. Якщо у вас є шаблон, яким ви бажаєте поділитись з іншими, будь ласка, [зробіть Pull Request](https://github.com/starship/starship/edit/master/docs/presets/README.md) з оновленнями для цього файлу! 😊

Щоб отримати додаткову інформацію про використання шаблону, просто натисніть на зображення.

## [Nerd Font Symbols](./nerd-font.md)

Цей стиль змінює символи для кожного модуля на символи з Nerd Font.

[![Скріншот шаблона Nerd Font Symbols](/presets/img/nerd-font-symbols.png "Натисніть для перегляду шаблона No Nerd Font")](./nerd-font)

## [No Nerd Fonts](./no-nerd-font.md)

Цей стиль змінює символи для кількох модулів, щоб жодні символи Nerd Font не використовувалися в командному рядку.

::: tip

Цей шаблон стане стандартним в [майбутньому випуску starship](https://github.com/starship/starship/pull/3544).

:::

[Натисніть для перегляду шаблона No Nerd Font](./no-nerd-font)

## [Bracketed Segments](./bracketed-segments.md)

Шаблон змінює формат всіх вбудованих модулів для показу їх частин в дужках замість використання стандартних в Starship слів ("via", "on", і т.д.).

[![Скріншот шаблона Bracketed Segments](/presets/img/bracketed-segments.png "Натисніть, щоб переглянути шаблон Bracketed Segments")](./bracketed-segments)

## [Plain Text Symbols](./plain-text.md)

Цей шаблон замінює символи в кожному модулі звичайним текстом. Це ваш вибір, якщо у вас немає доступу до символів Unicode.

[![Скріншот шаблона Plain Text Symbols](/presets/img/plain-text-symbols.png "Натисніть для перегляду шаблона Plain Text Symbols")](./plain-text)

## [No Runtime Versions](./no-runtimes.md)

Шаблон приховує версію поточного інтерпретатора для мов програмування. Якщо ви працюєте в контейнерах або віртуалізованих середовищах, то це для вас!

[![Скріншот шаблона Hide Runtime Versions](/presets/img/no-runtime-versions.png "Натисніть, щоб переглянути шаблон No Runtime Versions")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

Цей шаблон не показує іконок, якщо інструмент не знайдено.

[![Скріншот шаблона No Empty Icons](/presets/img/no-empty-icons.png "Натисніть, щоб переглянути шаблон No Runtime Versions")](./no-empty-icons.md)

## [Pure Prompt](./pure-preset.md)

Цей шаблон імітує зовнішній вигляд і поведінку [Pure](https://github.com/sindresorhus/pure).

[![Скріншот шаблона Pure Prompt](/presets/img/pure-preset.png "Натисніть для перегляду шаблона Pure Prompt")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Шаблон створений під враженням від [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). Він також показує як працює шлях підстановки в starship.

[![Скріншот шаблона Pastel Powerline](/presets/img/pastel-powerline.png "Натисніть для перегляду шаблона Pastel Powerline")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

Цей шаблон створений під враженням від [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Скріншот шаблона Tokyo Night](/presets/img/tokyo-night.png "Натисніть, щоб переглянути шаблон Токіо Night")](./tokyo-night)

## [Gruvbox Rainbow](./gruvbox-rainbow.md)

Цей шаблон створено під впливом [Pastel Powerline](./pastel-powerline.md) та [Tokyo Night](./tokyo-night.md).

[![Скріншот шаблона Gruvbox Rainbow](/presets/img/gruvbox-rainbow.png "Натисніть, щоб переглянути шаблон Gruvbox Rainbow")](./gruvbox-rainbow)

## [Jetpack](./jetpack.md)

Цей псевдомінімалістичний шаблон створений під враженням від [geometry](https://github.com/geometry-zsh/geometry) та [spaceship](https://github.com/spaceship-prompt/spaceship-prompt).

[![Скріншот шаблона Jetpack](/presets/img/jetpack.png "Натисніть для перегляду шаблона  Jetpack")](./jetpack)

## [Catppuccin Powerline](./catppuccin-powerline.md)

Цей шаблон є трохи зміненою версією [Gruvbox Rainbow](./gruvbox-rainbow.md), що використовує палітру [Catppuccin](https://github.com/catppuccin/catppuccin).

[![Скріншот шаблона Catppuccin Powerline](/presets/img/catppuccin-powerline.png "Натисніть, щоб переглянути шаблон Catppucin Powerline")](./catppuccin-powerline)

==> starship-1.24.2.tar.gz: starship-1.24.2/docs/uk-UA/presets/README.md <==
# Шаблони

Тут ви можете переглянути добірку шаблонів налаштувань, створених спільнотою Starship. Якщо у вас є шаблон, яким ви бажаєте поділитись з іншими, будь ласка, [зробіть Pull Request](https://github.com/starship/starship/edit/master/docs/presets/README.md) з оновленнями для цього файлу! 😊

Щоб отримати додаткову інформацію про використання шаблону, просто натисніть на зображення.

## [Nerd Font Symbols](./nerd-font.md)

Цей стиль змінює символи для кожного модуля на символи з Nerd Font.

[![Скріншот шаблона Nerd Font Symbols](/presets/img/nerd-font-symbols.png "Натисніть для перегляду шаблона No Nerd Font")](./nerd-font)

## [No Nerd Fonts](./no-nerd-font.md)

Цей стиль змінює символи для кількох модулів, щоб жодні символи Nerd Font не використовувалися в командному рядку.

> [!TIP] Цей шаблон стане стандартним [у наступних випусках starship](https://github.com/starship/starship/pull/3544).

[Натисніть для перегляду шаблона No Nerd Font](./no-nerd-font)

## [Bracketed Segments](./bracketed-segments.md)

Шаблон змінює формат всіх вбудованих модулів для показу їх частин в дужках замість використання стандартних в Starship слів ("via", "on", і т.д.).

[![Скріншот шаблона Bracketed Segments](/presets/img/bracketed-segments.png "Натисніть, щоб переглянути шаблон Bracketed Segments")](./bracketed-segments)

## [Plain Text Symbols](./plain-text.md)

Цей шаблон замінює символи в кожному модулі звичайним текстом. Це ваш вибір, якщо у вас немає доступу до символів Unicode.

[![Скріншот шаблона Plain Text Symbols](/presets/img/plain-text-symbols.png "Натисніть для перегляду шаблона Plain Text Symbols")](./plain-text)

## [No Runtime Versions](./no-runtimes.md)

Шаблон приховує версію поточного інтерпретатора для мов програмування. Якщо ви працюєте в контейнерах або віртуалізованих середовищах, то це для вас!

[![Скріншот шаблона Hide Runtime Versions](/presets/img/no-runtime-versions.png "Натисніть, щоб переглянути шаблон No Runtime Versions")](./no-runtimes)

## [No Empty Icons](./no-empty-icons.md)

Цей шаблон не показує іконок, якщо інструмент не знайдено.

[![Скріншот шаблона No Empty Icons](/presets/img/no-empty-icons.png "Натисніть, щоб переглянути шаблон No Runtime Versions")](./no-empty-icons.md)

## [Pure Prompt](./pure-preset.md)

Цей шаблон імітує зовнішній вигляд і поведінку [Pure](https://github.com/sindresorhus/pure).

[![Скріншот шаблона Pure Prompt](/presets/img/pure-preset.png "Натисніть для перегляду шаблона Pure Prompt")](./pure-preset)

## [Pastel Powerline](./pastel-powerline.md)

Шаблон створений під враженням від [M365Princess](https://github.com/JanDeDobbeleer/oh-my-posh/blob/main/themes/M365Princess.omp.json). Він також показує як працює шлях підстановки в starship.

[![Скріншот шаблона Pastel Powerline](/presets/img/pastel-powerline.png "Натисніть для перегляду шаблона Pastel Powerline")](./pastel-powerline)

## [Tokyo Night](./tokyo-night.md)

Цей шаблон створений під враженням від [tokyo-night-vscode-theme](https://github.com/enkia/tokyo-night-vscode-theme).

[![Скріншот шаблона Tokyo Night](/presets/img/tokyo-night.png "Натисніть, щоб переглянути шаблон Токіо Night")](./tokyo-night)

## [Gruvbox Rainbow](./gruvbox-rainbow.md)

Цей шаблон створено під впливом [Pastel Powerline](./pastel-powerline.md) та [Tokyo Night](./tokyo-night.md).

[![Скріншот шаблона Gruvbox Rainbow](/presets/img/gruvbox-rainbow.png "Натисніть, щоб переглянути шаблон Gruvbox Rainbow")](./gruvbox-rainbow)

## [Jetpack](./jetpack.md)

Цей псевдомінімалістичний шаблон створений під враженням від [geometry](https://github.com/geometry-zsh/geometry) та [spaceship](https://github.com/spaceship-prompt/spaceship-prompt).

[![Скріншот шаблона Jetpack](/presets/img/jetpack.png "Натисніть для перегляду шаблона  Jetpack")](./jetpack)

## [Catppuccin Powerline](./catppuccin-powerline.md)

Цей шаблон є трохи зміненою версією [Gruvbox Rainbow](./gruvbox-rainbow.md), що використовує палітру [Catppuccin](https://github.com/catppuccin/catppuccin).

[![Скріншот шаблона Catppuccin Powerline](/presets/img/catppuccin-powerline.png "Натисніть, щоб переглянути шаблон Catppucin Powerline")](./catppuccin-powerline)
